
clear all
close all

%Measured data
a = load('..\data\measured_sudden_exp_all.txt');

%Grid
fid = fopen('..\runs\suddenexpand_tele.tel','r');
fscanf(fid,'%s\n',1);
b=fscanf(fid,'%f %f %f %f\n',4);
theta = b(1); x0=b(2); y0=b(3); ncells=b(4);
c=fscanf(fid,'%d %f %f %f %f %d %d %d %d %d %d %d %d %f\n',ncells*14);
fclose(fid);
dat = reshape(c,14,ncells)';

%Solution
sol = readcmsh5('..\runs\suddenexpand_tele_sol.h5');
t = sol.Current_Magnitude.Times;
mag = sol.Current_Magnitude.Values(:,end);
vel = sol.Current_Velocity.Values(:,:,end);

x = dat(:,2)+x0-0.05;
y = dat(:,3)+y0;
[xi,yi] = meshgrid(0:1:5,0.01:0.05:1.19);
z = double(vel(1,:)');
u0 = griddata(x,y,z,xi,yi);

%Plotting
figure
xxi = ones(8,1)*(0:1:5);
h = plot(a(:,1:2:end)+xxi,a(:,2:2:end),'ro',u0+xi,yi,'b-','linewidth',2);
set(gca,'ylim',[0 1.2],'xlim',[-1 6])
xlabel('Current velocity in m/s plus horizontal distance in m')
ylabel('Distance, m')
legend([h(1),h(end)],'Measured','Calculated')

% return
%Statistics (on analytical solution points)
rmse = zeros(6,1);
nrmse = rmse; 
nmae = rmse; 
R2 = rmse; 
B = R2;
for i=1:6
    yc=interp1(yi(:,i),u0(:,i),a(:,2*i));
    ym=a(:,2*(i-1)+1);
    ind=isfinite(ym);
    ym=ym(ind);
    yc=yc(ind);
%     plot(ym,yc,'.')
    rmse(i) = sqrt(mean((yc-ym).^2));
    if i>1
        nrmse(i) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
        nmae(i) = mean(abs((yc-ym)))/(max(ym)-min(ym));
    else
        nrmse(i) = sqrt(mean((yc-ym).^2))/max(ym);
        nmae(i) = mean(abs((yc-ym)))/max(ym);
    end
    R = corrcoef(yc,ym);
    R2(i) = R(1,2).^2;
    B(i) = mean(yc-ym);
end


return

